@@ -5,7 +5,7 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.01";
+$VERSION = "1.10";
 
 =head1 NAME
 
@@ -91,8 +91,18 @@ sub CleanSlate {
 # }}}
 
 # {{{ sub _Handle
+
+=head2 _Handle  [DBH]
+
+Get or set this object's DBI database handle.
+
+=cut
+
 sub _Handle {
     my $self = shift;
+    if (@_) {
+        $self->{'DBIxHandle'} = shift;
+    }
     return ( $self->{'DBIxHandle'} );
 }
 
@@ -291,7 +301,6 @@ sub _DistinctQuery {
 
     # XXX - Postgres gets unhappy with distinct and OrderBy aliases
     if ($self->{order_clause} =~ /(?<!main)\./) {
-	$self->DEBUG(1);
         $$statementref = "SELECT main.* FROM $$statementref";
     }
     else {
@@ -628,7 +637,7 @@ sub Limit {
         #if we're explicitly told not to to quote the value or
         # we're doing an IS or IS NOT (null), don't quote the operator.
 
-        if ( $args{'QUOTEVALUE'} && $args{'OPERATOR'} !~ /IS/ ) {
+        if ( $args{'QUOTEVALUE'} && $args{'OPERATOR'} !~ /IS/i ) {
             my $tmp = $self->_Handle->dbh->quote( $args{'VALUE'} );
 
             # Accomodate DBI drivers that don't understand UTF8
@@ -1080,7 +1089,7 @@ sub Join {
     my %args = (
         TYPE   => 'normal',
         FIELD1 => undef,
-        ALIAS1 => undef,
+        ALIAS1 => 'main',
         TABLE2 => undef,
         FIELD2 => undef,
         ALIAS2 => undef,
@@ -1439,7 +1448,7 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 2001 Jesse Vincent, jesse@fsck.com.
+Copyright (c) 2001-2004 Jesse Vincent, jesse@fsck.com.
 
 All rights reserved.
 
